@@ -22,7 +22,7 @@ pbWald <- function(mod, mod_null, B = 1000) {
   restrictions <- tmp$mu
   restrictions.phi <- tmp$phi
   t.observed <- try(waldchisq_test(mod, restrictions = restrictions, restrictions.phi = restrictions.phi), silent = TRUE)
-  if (class(t.observed) == "try-error") {
+  if (inherits(t.observed, "try-error")) {
     return(NA)
   }
 
